==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/security/SecurityInfrastructureException.hpp <==
#ifndef _COM_SUN_STAR_SECURITY_SECURITYINFRASTRUCTUREEXCEPTION_HPP_
#define _COM_SUN_STAR_SECURITY_SECURITYINFRASTRUCTUREEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SECURITY_SECURITYINFRASTRUCTUREEXCEPTION_HDL_
#include "com/sun/star/security/SecurityInfrastructureException.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_SECURITYEXCEPTION_HPP_
#include "com/sun/star/uno/SecurityException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace security {

inline SecurityInfrastructureException::SecurityInfrastructureException() SAL_THROW( () )
    : ::com::sun::star::uno::SecurityException()
{ }

inline SecurityInfrastructureException::SecurityInfrastructureException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_) SAL_THROW( () )
    : ::com::sun::star::uno::SecurityException(Message_, Context_)
{ }

SecurityInfrastructureException::SecurityInfrastructureException(SecurityInfrastructureException const & the_other): ::com::sun::star::uno::SecurityException(the_other) {}

SecurityInfrastructureException::~SecurityInfrastructureException() {}

SecurityInfrastructureException & SecurityInfrastructureException::operator =(SecurityInfrastructureException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::uno::SecurityException::operator =(the_other);
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::security::SecurityInfrastructureException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.security.SecurityInfrastructureException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_SECURITY_SECURITYINFRASTRUCTUREEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/security/SecurityInfrastructureException.hpp <==
#ifndef _COM_SUN_STAR_SECURITY_SECURITYINFRASTRUCTUREEXCEPTION_HPP_
#define _COM_SUN_STAR_SECURITY_SECURITYINFRASTRUCTUREEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SECURITY_SECURITYINFRASTRUCTUREEXCEPTION_HDL_
#include "com/sun/star/security/SecurityInfrastructureException.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_SECURITYEXCEPTION_HPP_
#include "com/sun/star/uno/SecurityException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace security {

inline SecurityInfrastructureException::SecurityInfrastructureException() SAL_THROW( () )
    : ::com::sun::star::uno::SecurityException()
{ }

inline SecurityInfrastructureException::SecurityInfrastructureException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_) SAL_THROW( () )
    : ::com::sun::star::uno::SecurityException(Message_, Context_)
{ }

SecurityInfrastructureException::SecurityInfrastructureException(SecurityInfrastructureException const & the_other): ::com::sun::star::uno::SecurityException(the_other) {}

SecurityInfrastructureException::~SecurityInfrastructureException() {}

SecurityInfrastructureException & SecurityInfrastructureException::operator =(SecurityInfrastructureException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::uno::SecurityException::operator =(the_other);
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace security {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::security::SecurityInfrastructureException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.security.SecurityInfrastructureException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::security::SecurityInfrastructureException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::security::SecurityInfrastructureException >::get();
}

#endif // _COM_SUN_STAR_SECURITY_SECURITYINFRASTRUCTUREEXCEPTION_HPP_
